

************************************************************************************* Replication Code for "The Heterogeneous Role of Party Affiliation in the Runner-Up Effect"

******************************************************************************** Figure 1 - RD Plots

**USE Replication - Main Analysis.dta**

******************** Figure 1(a) - Recontesting Probability - All Candidates

capture program drop rdplotting
program rdplotting
version 14

syntax varlist(min = 5), xub(real) xlb(real) xint(real) yub(real) ylb(real) yint(real) title(string)
tokenize `varlist'
local meanx "`1'"
local meany "`2'"
local yhat "`3'"
local score "`4'"
local runvar "`5'"
/*
local lbci "`4'"
local treat "`5'"
*/
twoway  /*
*/ (scatter `meany' `meanx' if `score' < 0 & `meany' >= `ylb' & `meany' <= `yub', msize(small) mc(ebblue*0.5))/*
*/ (scatter `meany' `meanx' if `score' >= 0 & `meany' >= `ylb' & `meany' <= `yub', msize(small) mc(orange*0.5))/*
*/(line `yhat' `runvar' if `score' < 0 & `runvar' >= `xlb' & `runvar' < 0, lc(ebblue) lw(medthick))/*
*/(line `yhat' `runvar' if `score' >= 0 & `runvar' >= 0 & `runvar' <= `xub', lc(orange) lw(medthick)) /*
*/(scatteri `yub' 0 `ylb' 0 , recast(line) lc(black) lw(thin)), /*
*/xlabel(`xlb'(`xint')`xub', tlw(thin) labs(small) grid glw(vthin)) ylabel(`ylb'(`yint')`yub', labs(small) angle(horizontal) grid glw(vthin)) xmtick(##1)/*
*/ ymtick(##1, grid) ytitle("`title'", size(small)) xtitle("Vote share difference between 2nd and 3rd in Year t", size(small))/*
*/ graphregion(color(white) margin(1 1 -2 -2)) name(`name', replace) plotregion(lcolor(black) lw(thin)) /*
*/  aspect(0.7) xline(0, lc(black) lw(thin)) ysc(lw(none)) xsc(lw(none)) /*
*/ legend(order(3 4) label(3 "Control") label(4 "Treated") col(1) region(lc(white) c(white)) size(small) position(1) ring(0)) 
 

end


*** RD Plot

qui rdplot recontest mv if -0.50<= mv & mv <= 0.50, hide nbins(24 24) binselect(esmv) kernel(triangular) h(0.50 0.50) p(2) graph_options(title("RD Plot: Recontesting") ytitle( P(recontesting) at t+1) xtitle(Vote share difference between 2nd and 3rd in Year t) graphregion(color(white))) genvars

sort mv
rdplotting rdplot_mean_x  rdplot_mean_y  rdplot_hat_y  rdplot_id  mv, xlb(-0.5) xub(0.5) xint(0.1) ylb(0) yub(0.60) yint(0.1) title(P(Recontesting) at t+1)


******************** Figure 1(b) - Winning Probability - All Candidates

drop rdplot_id rdplot_N rdplot_min_bin rdplot_max_bin rdplot_mean_bin rdplot_mean_x rdplot_mean_y rdplot_se_y rdplot_ci_l rdplot_ci_r rdplot_hat_y

qui rdplot winning mv if -0.50<= mv & mv <= 0.50, hide nbins(24 24) binselect(esmv) kernel(triangular) h(0.50 0.50) p(2) graph_options(title("RD Plot: Winning") ytitle( P(winning) at t+1) xtitle(Vote share difference between 2nd and 3rd in Year t) graphregion(color(white))) genvars

sort mv
rdplotting rdplot_mean_x  rdplot_mean_y  rdplot_hat_y  rdplot_id  mv, xlb(-0.5) xub(0.5) xint(0.1) ylb(0) yub(0.4) yint(0.1) title(P(Winning) at t+1)


******************** Figure 1(c) - Recontesting Probability - Major Party Candidates

drop rdplot_id rdplot_N rdplot_min_bin rdplot_max_bin rdplot_mean_bin rdplot_mean_x rdplot_mean_y rdplot_se_y rdplot_ci_l rdplot_ci_r rdplot_hat_y

qui rdplot recontest mv if -0.50<= mv & mv <= 0.50 & major_m==1, hide nbins(24 24) binselect(esmv) kernel(triangular) h(0.50 0.50) p(2) graph_options(title("RD Plot: Recontesting - Major Candidates") ytitle( P(recontesting) at t+1) xtitle(Vote share difference between 2nd and 3rd in Year t) graphregion(color(white))) genvars

sort mv
rdplotting rdplot_mean_x  rdplot_mean_y  rdplot_hat_y  rdplot_id  mv, xlb(-0.5) xub(0.5) xint(0.1) ylb(0) yub(0.60) yint(0.1) title(P(Recontesting) at t+1)


******************** Figure 1(d) - Winning Probability - Major Party Candidates

drop rdplot_id rdplot_N rdplot_min_bin rdplot_max_bin rdplot_mean_bin rdplot_mean_x rdplot_mean_y rdplot_se_y rdplot_ci_l rdplot_ci_r rdplot_hat_y

qui rdplot winning mv if -0.50<= mv & mv <= 0.50 & major_m==1, hide nbins(24 24) binselect(esmv) kernel(triangular) h(0.50 0.50) p(2) graph_options(title("RD Plot: Winning") ytitle( P(winning) at t+1) xtitle(Vote share difference between 2nd and 3rd in Year t) graphregion(color(white))) genvars

sort mv
rdplotting rdplot_mean_x  rdplot_mean_y  rdplot_hat_y  rdplot_id  mv, xlb(-0.5) xub(0.5) xint(0.1) ylb(0) yub(0.4) yint(0.1)  title(P(Winning) at t+1)


******************** Figure 1(e) - Recontesting Probability - Minor Party Candidates

drop rdplot_id rdplot_N rdplot_min_bin rdplot_max_bin rdplot_mean_bin rdplot_mean_x rdplot_mean_y rdplot_se_y rdplot_ci_l rdplot_ci_r rdplot_hat_y

qui rdplot recontest mv if -0.50<= mv & mv <= 0.50 & major_m==0, hide nbins(24 24) binselect(esmv) kernel(triangular) h(0.50 0.50) p(2) graph_options(title("RD Plot: Recontesting - Major Candidates") ytitle( P(recontesting) at t+1) xtitle(Vote share difference between 2nd and 3rd in Year t) graphregion(color(white))) genvars

sort mv
rdplotting rdplot_mean_x  rdplot_mean_y  rdplot_hat_y  rdplot_id  mv, xlb(-0.5) xub(0.5) xint(0.1) ylb(0) yub(0.60) yint(0.1) title(P(Recontesting) at t+1)


******************** Figure 1(f) - Winning Probability - Minor Party Candidates

drop rdplot_id rdplot_N rdplot_min_bin rdplot_max_bin rdplot_mean_bin rdplot_mean_x rdplot_mean_y rdplot_se_y rdplot_ci_l rdplot_ci_r rdplot_hat_y

qui rdplot winning mv if -0.50<= mv & mv <= 0.50 & major_m==0, hide nbins(24 24) binselect(esmv) kernel(triangular) h(0.50 0.50) p(2) graph_options(title("RD Plot: Winning") ytitle( P(winning) at t+1) xtitle(Vote share difference between 2nd and 3rd in Year t) graphregion(color(white))) genvars

sort mv
rdplotting rdplot_mean_x  rdplot_mean_y  rdplot_hat_y  rdplot_id  mv, xlb(-0.5) xub(0.5) xint(0.1) ylb(0) yub(0.4) yint(0.1) title(P(Winning) at t+1)



******************************************************************************** Table 1 - Main Results

**USE Replication - Main Analysis.dta**

*** Recontest

rdrobust recontest mv, p(1) all vce(cluster ac) bwselect(mserd) masspoints(off)
rdrobust recontest mv, p(1) h(0.072) all vce(cluster ac) bwselect(mserd) masspoints(off)
rdrobust recontest mv, p(1) h(0.288) all vce(cluster ac) bwselect(mserd) masspoints(off)
rdrobust recontest mv, p(0) all vce(cluster ac) bwselect(mserd) masspoints(off)
rdrobust recontest mv, p(2) all vce(cluster ac) bwselect(mserd) masspoints(off)

*** Winning

rdrobust winning mv, p(1) all vce(cluster ac) bwselect(mserd) masspoints(off)
rdrobust winning mv, p(1) h(0.085) all vce(cluster ac) bwselect(mserd) masspoints(off)
rdrobust winning mv, p(1) h(0.34) all vce(cluster ac) bwselect(mserd) masspoints(off)
rdrobust winning mv, p(0) all vce(cluster ac) bwselect(mserd) masspoints(off)
rdrobust winning mv, p(2) all vce(cluster ac) bwselect(mserd) masspoints(off)

*** Control Group Mean

gen temp=0 in 1

lpoly recontest mv if mv<0, kernel(triangle) bwidth(0.144) at(temp) gen(x) nograph
drop x
lpoly winning mv if mv<0, kernel(triangle) bwidth(0.1680) at(temp) gen(x) nograph
drop x
drop temp


***** Panel B - Major Party Candidates

*** Recontest

rdrobust recontest mv if major_m==1, p(1) all vce(cluster ac) bwselect(mserd) masspoints(off)
rdrobust recontest mv if major_m==1, p(1) h(0.064) all vce(cluster ac) bwselect(mserd) masspoints(off)
rdrobust recontest mv if major_m==1, p(1) h(0.256) all vce(cluster ac) bwselect(mserd) masspoints(off)
rdrobust recontest mv if major_m==1, p(0) all vce(cluster ac) bwselect(mserd) masspoints(off)
rdrobust recontest mv if major_m==1, p(2) all vce(cluster ac) bwselect(mserd) masspoints(off)

*** Winning

rdrobust winning mv if major_m==1, p(1) all vce(cluster ac) bwselect(mserd) masspoints(off)
rdrobust winning mv if major_m==1, p(1) h(0.057) all vce(cluster ac) bwselect(mserd) masspoints(off)
rdrobust winning mv if major_m==1, p(1) h(0.228) all vce(cluster ac) bwselect(mserd) masspoints(off)
rdrobust winning mv if major_m==1, p(0) all vce(cluster ac) bwselect(mserd) masspoints(off)
rdrobust winning mv if major_m==1, p(2) all vce(cluster ac) bwselect(mserd) masspoints(off)

*** Control Group Mean

gen temp=0 in 1

lpoly recontest mv if mv<0 & major_m==1, kernel(triangle) bwidth(0.127) at(temp) gen(x) nograph
drop x
lpoly winning mv if mv<0 & major_m==1, kernel(triangle) bwidth(0.113) at(temp) gen(x) nograph
drop x
drop temp


***** Panel C - Minor Party Candidates

*** Recontest

rdrobust recontest mv if major_m==0, p(1) all vce(cluster ac) bwselect(mserd) masspoints(off)
rdrobust recontest mv if major_m==0, p(1) h(0.0675) all vce(cluster ac) bwselect(mserd) masspoints(off)
rdrobust recontest mv if major_m==0, p(1) h(0.27) all vce(cluster ac) bwselect(mserd) masspoints(off)
rdrobust recontest mv if major_m==0, p(0) all vce(cluster ac) bwselect(mserd) masspoints(off)
rdrobust recontest mv if major_m==0, p(2) all vce(cluster ac) bwselect(mserd) masspoints(off)

*** Winning

rdrobust winning mv if major_m==0, p(1) all vce(cluster ac) bwselect(mserd) masspoints(off)
rdrobust winning mv if major_m==0, p(1) h(0.062) all vce(cluster ac) bwselect(mserd) masspoints(off)
rdrobust winning mv if major_m==0, p(1) h(0.248) all vce(cluster ac) bwselect(mserd) masspoints(off)
rdrobust winning mv if major_m==0, p(0) all vce(cluster ac) bwselect(mserd) masspoints(off)
rdrobust winning mv if major_m==0, p(2) all vce(cluster ac) bwselect(mserd) masspoints(off)

*** Control Group Mean

gen temp=0 in 1

lpoly recontest mv if mv<0 & major_m==0, kernel(triangle) bwidth(0.135) at(temp) gen(x) nograph
drop x
lpoly winning mv if mv<0 & major_m==0, kernel(triangle) bwidth(0.124) at(temp) gen(x) nograph
drop x
drop temp


***** Panel D - Independent Candidates

*** Recontest

rdrobust recontest mv if ind==1, p(1) all vce(cluster ac) bwselect(mserd) masspoints(off)
rdrobust recontest mv if ind==1, p(1) h(0.076) all vce(cluster ac) bwselect(mserd) masspoints(off)
rdrobust recontest mv if ind==1, p(1) h(0.304) all vce(cluster ac) bwselect(mserd) masspoints(off)
rdrobust recontest mv if ind==1, p(0) all vce(cluster ac) bwselect(mserd) masspoints(off)
rdrobust recontest mv if ind==1, p(2) all vce(cluster ac) bwselect(mserd) masspoints(off)

*** Winning

rdrobust winning mv if ind==1, p(1) all vce(cluster ac) bwselect(mserd) masspoints(off)
rdrobust winning mv if ind==1, p(1) h(0.076) all vce(cluster ac) bwselect(mserd) masspoints(off)
rdrobust winning mv if ind==1, p(1) h(0.304) all vce(cluster ac) bwselect(mserd) masspoints(off)
rdrobust winning mv if ind==1, p(0) all vce(cluster ac) bwselect(mserd) masspoints(off)
rdrobust winning mv if ind==1, p(2) all vce(cluster ac) bwselect(mserd) masspoints(off)

*** Control Group Mean

gen temp=0 in 1

lpoly recontest mv if mv<0 & ind==1, kernel(triangle) bwidth(0.151) at(temp) gen(x) nograph
drop x
lpoly winning mv if mv<0 & ind==1, kernel(triangle) bwidth(0.152) at(temp) gen(x) nograph
drop x
drop temp



******************************************************************************** Table A1 - Covariates Balancing Test  

*** Panel A

**USE Replication - Main Analysis.dta**

rdcont mv
rdcont mv if major_m==1
rdcont mv if major_m==0
rdcont mv if ind==1


*** Panel B

**USE Replication - Balancing Analysis.dta**

*** Instructions to run the rdperm command are as follows ***
*** Step 1: Download the rdperm package online from  "https://sites.northwestern.edu/iac879/2015/10/26/stata-code-for-rdperm/" - The link was accessed most recently on November 20th, 2022 *** 
*** Step 2: Run the command "capture program drop rdperm" from the file titled 'rdperm_example.do' available from the rdperm zip file ***
*** Step 3: Then run the ado file titled 'rdperm.ado' ***
*** Note: The p-values can be slightly different each time the rdperm command is run for a variable ***


*** Baseline

foreach i in recontested winning votes_margin_m major_party ed num_crim adr_major_crime{
rdperm mv_balancing `i', c(0)
}


*** Major Party Candidates

foreach i in recontested winning votes_margin_m major_party ed num_crim adr_major_crime{
rdperm mv_balancing `i' if major_u==1, c(0)
}


*** Minor Party Candidates

foreach i in recontested winning votes_margin_m major_party ed num_crim adr_major_crime{
rdperm mv_balancing `i' if major_u==0, c(0)
}


*** Independent Candidates

foreach i in recontested winning votes_margin_m major_party ed num_crim adr_major_crime{
rdperm mv_balancing `i' if ind==1, c(0)
}



******************************************************************************** Table A2 - Quality of the Opposition

**USE Replication - Main Analysis.dta**

*** Non-Major party candidate (second) and Major party candidate (third)

rdrobust recontest mv if nonmajor_major==2, p(1) all vce(cluster ac) bwselect(mserd) masspoints(off)
rdrobust winning mv if nonmajor_major==2, p(1) all vce(cluster ac) bwselect(mserd) masspoints(off)

gen temp=0 in 1
lpoly recontest mv if mv<0 & nonmajor_major==2, kernel(triangle) bwidth(0.092) at(temp) gen(x) nograph
drop x
lpoly winning mv if mv<0 & nonmajor_major==2, kernel(triangle) bwidth(0.083) at(temp) gen(x) nograph
drop x
drop temp


*** Non-Major party candidate (second) and Non-Major party candidate (third) 

rdrobust recontest mv if nonmajor_nonmajor==2, p(1) all vce(cluster ac) bwselect(mserd) masspoints(off)
rdrobust winning mv if nonmajor_nonmajor==2, p(1) all vce(cluster ac) bwselect(mserd) masspoints(off)

gen temp=0 in 1
lpoly recontest mv if mv<0 & nonmajor_nonmajor==2, kernel(triangle) bwidth(0.166) at(temp) gen(x) nograph
drop x
lpoly winning mv if mv<0 & nonmajor_nonmajor==2, kernel(triangle) bwidth(0.180) at(temp) gen(x) nograph
drop x
drop temp


*** Both Candidates are from a Major party in the same constituency

rdrobust recontest mv if major_major==2, p(1) all vce(cluster ac) bwselect(mserd) masspoints(off)
rdrobust winning mv if major_major==2, p(1) all vce(cluster ac) bwselect(mserd) masspoints(off)

gen temp=0 in 1
lpoly recontest mv if mv<0 & major_major==2, kernel(triangle) bwidth(0.095) at(temp) gen(x) nograph
drop x
lpoly winning mv if mv<0 & major_major==2, kernel(triangle) bwidth(0.066) at(temp) gen(x) nograph
drop x
drop temp


*** Major party (second) and non-major party candidate (third)

rdrobust recontest mv if major_nonmajor==2, p(1) all vce(cluster ac) bwselect(mserd) masspoints(off)
rdrobust winning mv if major_nonmajor==2, p(1) all vce(cluster ac) bwselect(mserd) masspoints(off)

gen temp=0 in 1
lpoly recontest mv if mv<0 & major_nonmajor==2, kernel(triangle) bwidth(0.151) at(temp) gen(x) nograph
drop x
lpoly winning mv if mv<0 & major_nonmajor==2, kernel(triangle) bwidth(0.199) at(temp) gen(x) nograph
drop x
drop temp




******************************************************************************** Table A3 - Sensitivity exercise around the threshold definition of major parties

**USE Replication - Main Analysis.dta**

***** Panel A - Defining major party using 5% for seats won

* Major Party Candidates

rdrobust recontest mv if major_m5perc==1, p(1) all vce(cluster ac) bwselect(mserd) masspoints(off)
rdrobust winning mv if major_m5perc==1, p(1) all vce(cluster ac) bwselect(mserd) masspoints(off)

*** Control Group Mean

gen temp=0 in 1
lpoly recontest mv if mv<0 & major_m5perc==1, kernel(triangle) bwidth(0.120) at(temp) gen(x) nograph
drop x
lpoly winning mv if mv<0 & major_m5perc==1, kernel(triangle) bwidth(0.112) at(temp) gen(x) nograph
drop x
drop temp


* Minor Party Candidates

rdrobust recontest mv if major_m5perc==0, p(1) all vce(cluster ac) bwselect(mserd) masspoints(off)
rdrobust winning mv if major_m5perc==0, p(1) all vce(cluster ac) bwselect(mserd) masspoints(off)

*** Control Group Mean

gen temp=0 in 1
lpoly recontest mv if mv<0 & major_m5perc==0, kernel(triangle) bwidth(0.115) at(temp) gen(x) nograph
drop x
lpoly winning mv if mv<0 & major_m5perc==0, kernel(triangle) bwidth(0.113) at(temp) gen(x) nograph
drop x
drop temp


***** Panel B - Defining major party using 10% for seats won

* Major Party Candidates

rdrobust recontest mv if major_m10perc==1, p(1) all vce(cluster ac) bwselect(mserd) masspoints(off)
rdrobust winning mv if major_m10perc==1, p(1) all vce(cluster ac) bwselect(mserd) masspoints(off)

*** Control Group Mean

gen temp=0 in 1
lpoly recontest mv if mv<0 & major_m10perc==1, kernel(triangle) bwidth(0.127) at(temp) gen(x) nograph
drop x
lpoly winning mv if mv<0 & major_m10perc==1, kernel(triangle) bwidth(0.114) at(temp) gen(x) nograph
drop x
drop temp


* Minor Party Candidates

rdrobust recontest mv if major_m10perc==0, p(1) all vce(cluster ac) bwselect(mserd) masspoints(off)
rdrobust winning mv if major_m10perc==0, p(1) all vce(cluster ac) bwselect(mserd) masspoints(off)

*** Control Group Mean

gen temp=0 in 1
lpoly recontest mv if mv<0 & major_m10perc==0, kernel(triangle) bwidth(0.130) at(temp) gen(x) nograph
drop x
lpoly winning mv if mv<0 & major_m10perc==0, kernel(triangle) bwidth(0.119) at(temp) gen(x) nograph
drop x
drop temp


***** Panel C - Defining a party as major if it has won top two positions in an election and wins atleast 10% of the seats

* Major Party Candidates

rdrobust recontest mv if major_toptwo==1, p(1) all vce(cluster ac) bwselect(mserd) masspoints(off)
rdrobust winning mv if major_toptwo==1, p(1) all vce(cluster ac) bwselect(mserd) masspoints(off)

*** Control Group Mean

gen temp=0 in 1
lpoly recontest mv if mv<0 & major_toptwo==1, kernel(triangle) bwidth(0.139) at(temp) gen(x) nograph
drop x
lpoly winning mv if mv<0 & major_toptwo==1, kernel(triangle) bwidth(0.121) at(temp) gen(x) nograph
drop x
drop temp


* Minor Party Candidates

rdrobust recontest mv if major_toptwo==0, p(1) all vce(cluster ac) bwselect(mserd) masspoints(off)
rdrobust winning mv if major_toptwo==0, p(1) all vce(cluster ac) bwselect(mserd) masspoints(off)

*** Control Group Mean

gen temp=0 in 1
lpoly recontest mv if mv<0 & major_toptwo==0, kernel(triangle) bwidth(0.159) at(temp) gen(x) nograph
drop x
lpoly winning mv if mv<0 & major_toptwo==0, kernel(triangle) bwidth(0.143) at(temp) gen(x) nograph
drop x
drop temp


***** Panel D - Defining a party as major if it has won top four positions in an election and wins atleast 10% of the seats

* Major Party Candidates

rdrobust recontest mv if major_topfour==1, p(1) all vce(cluster ac) bwselect(mserd) masspoints(off)
rdrobust winning mv if major_topfour==1, p(1) all vce(cluster ac) bwselect(mserd) masspoints(off)

*** Control Group Mean

gen temp=0 in 1
lpoly recontest mv if mv<0 & major_topfour==1, kernel(triangle) bwidth(0.131) at(temp) gen(x) nograph
drop x
lpoly winning mv if mv<0 & major_topfour==1, kernel(triangle) bwidth(0.115) at(temp) gen(x) nograph
drop x
drop temp


* Minor Party Candidates

rdrobust recontest mv if major_topfour==0, p(1) all vce(cluster ac) bwselect(mserd) masspoints(off)
rdrobust winning mv if major_topfour==0, p(1) all vce(cluster ac) bwselect(mserd) masspoints(off)

*** Control Group Mean

gen temp=0 in 1
lpoly recontest mv if mv<0 & major_topfour==0, kernel(triangle) bwidth(0.130) at(temp) gen(x) nograph
drop x
lpoly winning mv if mv<0 & major_topfour==0, kernel(triangle) bwidth(0.118) at(temp) gen(x) nograph
drop x
drop temp


***** Panel E - Defining a party as major if its INC or BJP

* Major Party Candidates

rdrobust recontest mv if major_inc==1, p(1) all vce(cluster ac) bwselect(mserd) masspoints(off)
rdrobust winning mv if major_inc==1, p(1) all vce(cluster ac) bwselect(mserd) masspoints(off)

*** Control Group Mean

gen temp=0 in 1
lpoly recontest mv if mv<0 & major_inc==1, kernel(triangle) bwidth(0.130) at(temp) gen(x) nograph
drop x
lpoly winning mv if mv<0 & major_inc==1, kernel(triangle) bwidth(0.116) at(temp) gen(x) nograph
drop x
drop temp


* Minor Party Candidates

rdrobust recontest mv if major_inc==0, p(1) all vce(cluster ac) bwselect(mserd) masspoints(off)
rdrobust winning mv if major_inc==0, p(1) all vce(cluster ac) bwselect(mserd) masspoints(off)

*** Control Group Mean

gen temp=0 in 1
lpoly recontest mv if mv<0 & major_inc==0, kernel(triangle) bwidth(0.137) at(temp) gen(x) nograph
drop x
lpoly winning mv if mv<0 & major_inc==0, kernel(triangle) bwidth(0.138) at(temp) gen(x) nograph
drop x
drop temp



******************************************************************************** Figure A1 - Balancing Test Plots

**USE Replication - Balancing Analysis.dta**


******************** Figure A1(a) - Recontesting Probability at t-1

***** Recontest 

qui rdplot recontested mv_balancing if -0.50<= mv_balancing & mv_balancing <= 0.50, hide nbins(24 24) binselect(esmv) kernel(triangular) h(0.50 0.50) p(2) graph_options(title("RD Plot: Recontest") ytitle( P(recontest) at t-1) xtitle(Vote share difference between 2nd and 3rd in Year t) graphregion(color(white))) genvars

sort mv_balancing
rdplotting rdplot_mean_x  rdplot_mean_y  rdplot_hat_y  rdplot_id  mv_balancing, xlb(-0.5) xub(0.5) xint(0.1) ylb(0) yub(0.60) yint(0.1) title(P(recontesting) at t-1)


******************** Figure A1(b) - Winning Probability at t-1

***** RD Plot Codes - Winning

drop rdplot_id rdplot_N rdplot_min_bin rdplot_max_bin rdplot_mean_bin rdplot_mean_x rdplot_mean_y rdplot_se_y rdplot_ci_l rdplot_ci_r rdplot_hat_y

qui rdplot winning mv_balancing if -0.50<= mv_balancing & mv_balancing <= 0.50, hide nbins(24 24) binselect(esmv) kernel(triangular) h(0.50 0.50) p(2) graph_options(title("RD Plot: Winning") ytitle( P(winning) at t-1) xtitle(Vote share difference between 2nd and 3rd in Year t) graphregion(color(white))) genvars

sort mv_balancing
rdplotting rdplot_mean_x  rdplot_mean_y  rdplot_hat_y  rdplot_id  mv_balancing, xlb(-0.5) xub(0.5) xint(0.1) ylb(0) yub(0.40) yint(0.1) title(P(winning) at t-1)


******************** Figure A1(c) - Vote Share at t-1

***** RD Plot Codes - Vote Share

preserve
keep if recontest==1 //Keep only recontested candidates, else genvars doesn't work here
drop rdplot_id rdplot_N rdplot_min_bin rdplot_max_bin rdplot_mean_bin rdplot_mean_x rdplot_mean_y rdplot_se_y rdplot_ci_l rdplot_ci_r rdplot_hat_y
qui rdplot votes_margin_m mv_balancing if -0.50<= mv_balancing & mv_balancing <= 0.50, hide nbins(24 24) binselect(esmv) kernel(triangular) h(0.50 0.50) p(2) graph_options(title("RD Plot: Vote Share") ytitle( P(vote share) at t-1) xtitle(Vote share difference between 2nd and 3rd in Year t) graphregion(color(white))) genvars

sort mv_balancing
rdplotting rdplot_mean_x  rdplot_mean_y  rdplot_hat_y  rdplot_id  mv_balancing, xlb(-0.5) xub(0.5) xint(0.1) ylb(0) yub(0.60) yint(0.1) title(P(Vote Share) at t-1)

restore

******************** Figure A1(d) - Contesting from a Major Party at t-1

***** RD Plot Codes - Major Party

drop rdplot_id rdplot_N rdplot_min_bin rdplot_max_bin rdplot_mean_bin rdplot_mean_x rdplot_mean_y rdplot_se_y rdplot_ci_l rdplot_ci_r rdplot_hat_y

qui rdplot major_party mv_balancing if -0.50<= mv_balancing & mv_balancing <= 0.50, hide nbins(24 24) binselect(esmv) kernel(triangular) h(0.50 0.50) p(2) graph_options(title("RD Plot: Major Party") ytitle( P(major party) at t-1) xtitle(Vote share difference between 2nd and 3rd in Year t) graphregion(color(white))) genvars

sort mv_balancing
rdplotting rdplot_mean_x  rdplot_mean_y  rdplot_hat_y  rdplot_id  mv_balancing, xlb(-0.5) xub(0.5) xint(0.1) ylb(0) yub(1) yint(0.1) title(P(Major Party) at t-1)



******************************************************************************** Figure A2 - By Party Order

**USE Replication - Main Analysis.dta**

*** Recontest

rdrobust recontest mv if party_order_yearm==1 & ind==0, p(1) all vce(cluster ac) bwselect(mserd) masspoints(off)
rdrobust recontest mv if party_order_yearm==2 & ind==0, p(1) all vce(cluster ac) bwselect(mserd) masspoints(off)
rdrobust recontest mv if party_order_yearm==3 & ind==0, p(1) all vce(cluster ac) bwselect(mserd) masspoints(off)
rdrobust recontest mv if party_order_yearm==4 & ind==0, p(1) all vce(cluster ac) bwselect(mserd) masspoints(off)
rdrobust recontest mv if party_order_yearm==5 & ind==0, p(1) all vce(cluster ac) bwselect(mserd) masspoints(off)
rdrobust recontest mv if party_order_yearm==6 & ind==0, p(1) all vce(cluster ac) bwselect(mserd) masspoints(off)
rdrobust recontest mv if party_order_yearm==7 & ind==0, p(1) all vce(cluster ac) bwselect(mserd) masspoints(off)


************** To generate the party order plot for the variable 'recontest', run the following code

****** Step 1: Copy the coefficients and SEs from the above outputs to a new .dta file and name the variables as 'rd_recontest' and 'se_recontest', respectively *****
****** Step 2: Create the upper and lower bounds for the 90% CI using the following command *****

*** Generating Lower and Upper Bounds for DTE Graphs

gen rd_recontest_upper = rd_recontest + (1.65 * se_recontest)
gen rd_recontest_lower = rd_recontest - (1.65 * se_recontest)


*** Winning

rdrobust winning mv if party_order_yearm==1 & ind==0, p(1) all vce(cluster ac) bwselect(mserd) masspoints(off)
rdrobust winning mv if party_order_yearm==2 & ind==0, p(1) all vce(cluster ac) bwselect(mserd) masspoints(off)
rdrobust winning mv if party_order_yearm==3 & ind==0, p(1) all vce(cluster ac) bwselect(mserd) masspoints(off)
rdrobust winning mv if party_order_yearm==4 & ind==0, p(1) all vce(cluster ac) bwselect(mserd) masspoints(off)
rdrobust winning mv if party_order_yearm==5 & ind==0, p(1) all vce(cluster ac) bwselect(mserd) masspoints(off)
rdrobust winning mv if party_order_yearm==6 & ind==0, p(1) all vce(cluster ac) bwselect(mserd) masspoints(off)
rdrobust winning mv if party_order_yearm==7 & ind==0, p(1) all vce(cluster ac) bwselect(mserd) masspoints(off)


************** To generate the party order plot for the variable 'winning', run the following code

****** Step 1: Copy the coefficients and SEs from the above outputs to the same .dta file and name the variables as 'rd_winning' and 'se_winning', respectively *****
****** Step 2: Create the upper and lower bounds for the 90% CI using the following command *****

*** Generating Lower and Upper Bounds for DTE Graphs

gen rd_winning_upper = rd_winning + (1.65 * se_winning)
gen rd_winning_lower = rd_winning - (1.65 * se_winning)


***** Step 3: Run the following dyteplot code to generate the graphs

*** Plots for Party Order - Recontest

capture program drop dyteplot
program dyteplot
version 14

syntax varlist(min = 4), y1lb(real) y1ub(real) y1int(real) xlb(real) xub(real) xint(real) lpos(real) 
tokenize `varlist'
local xaxis "`1'"
local beta "`2'"
local ubci "`3'"
local lbci "`4'"

twoway (rcapsym `ubci' `lbci' `xaxis' /*if `ubci' <= `y1ub' & `lbci' >= `y1lb' & `xaxis' >= `xlb' & `xaxis' <= `xub'*/, m(d) msize(vsmall) mcolor(orange_red) lcolor(orange_red))/*
*/ (scatter `beta' `xaxis' /*if `ubci' <= `y1ub' & `lbci' >= `y1lb'*/ , m(o) mcolor(ebblue) /*c(l) lc(ebblue) lp(dash_dot))*/,/*
*/ yline(0, lc(black) lw(thin)) xline(0,lc(bluishgray) lw(thin)) xline(4, lc(bluishgray) lw(thin)) /*
*/ xlabel(`xlb'(`xint')`xub', labs(small) val) ymtick(##1) ylabel(`y1lb'(`y1int')`y1ub', labs(small)) /*
*/ ytitle("RD Treatment Effect", size(small)) xtitle("Party Order", size(small)) /*
*/ legend(order(2 1) label(2 "Treatment Effect") label(1 "90% C.I.") col(2) region(lc(white) c(none)) symx(*0.5) /*
*/ size(small) position(`lpos') ring(0)) plotregion(lcolor(black)) /*
*/ aspect(0.7) graphregion(color(white) margin(1 1 -2 -2)))


end



*** Plot Code

dyteplot party_order rd_recontest rd_recontest_upper rd_recontest_lower, y1lb(-0.10) y1ub(0.40) y1int(0.10) xlb(1) xub(7) xint(1) lpos(1)


*** Plots for Party Order - Winning

capture program drop dyteplot
program dyteplot
version 14

syntax varlist(min = 4), y1lb(real) y1ub(real) y1int(real) xlb(real) xub(real) xint(real) lpos(real) 
tokenize `varlist'
local xaxis "`1'"
local beta "`2'"
local ubci "`3'"
local lbci "`4'"

twoway (rcapsym `ubci' `lbci' `xaxis' /*if `ubci' <= `y1ub' & `lbci' >= `y1lb' & `xaxis' >= `xlb' & `xaxis' <= `xub'*/, m(d) msize(vsmall) mcolor(orange_red) lcolor(orange_red))/*
*/ (scatter `beta' `xaxis' /*if `ubci' <= `y1ub' & `lbci' >= `y1lb'*/ , m(o) mcolor(ebblue) /*c(l) lc(ebblue) lp(dash_dot))*/,/*
*/ yline(0, lc(black) lw(thin)) xline(0,lc(bluishgray) lw(thin)) xline(4, lc(bluishgray) lw(thin)) /*
*/ xlabel(`xlb'(`xint')`xub', labs(small) val) ymtick(##1) ylabel(`y1lb'(`y1int')`y1ub', labs(small)) /*
*/ ytitle("RD Treatment Effect", size(small)) xtitle("Party Order", size(small)) /*
*/ legend(order(2 1) label(2 "Treatment Effect") label(1 "90% C.I.") col(2) region(lc(white) c(none)) symx(*0.5) /*
*/ size(small) position(`lpos') ring(0)) plotregion(lcolor(black)) /*
*/ aspect(0.7) graphregion(color(white) margin(1 1 -2 -2)))


end



*** Plot Code

dyteplot party_order rd_winning rd_winning_upper rd_winning_lower, y1lb(-0.10) y1ub(0.40) y1int(0.10) xlb(1) xub(7) xint(1) lpos(1)


******************************************************************************** Figure A2 Manipulation around the cut-off - rddensity

**USE Replication - Main Analysis.dta**

rddensity mv, plot

rddensity mv if major_m==1, plot

rddensity mv if major_m==0, plot

rddensity mv if ind==1, plot


